@@ -9,10 +9,24 @@
 ###########################################################################################
 
 # pypi
+# # trying https://alembic.sqlalchemy.org/en/latest/naming.html#integration-of-naming-conventions-into-operations-autogenerate
+# from sqlalchemy import MetaData
+# from sqlalchemy.ext.declarative import declarative_base
+# from flask_sqlalchemy import SQLAlchemy, Model
 from flask_sqlalchemy import SQLAlchemy
 from flask_security import UserMixin, RoleMixin
 
 # set up database - SQLAlchemy() must be done after app.config SQLALCHEMY_* assignments
+# # trying https://alembic.sqlalchemy.org/en/latest/naming.html#integration-of-naming-conventions-into-operations-autogenerate
+# # probably missing the update required in env.py
+# meta = MetaData(naming_convention={
+#         "ix": "ix_%(column_0_label)s",
+#         "uq": "uq_%(table_name)s_%(column_0_name)s",
+#         "ck": "ck_%(table_name)s_%(constraint_name)s",
+#         "fk": "fk_%(table_name)s_%(column_0_name)s_%(referred_table_name)s",
+#         "pk": "pk_%(table_name)s"
+#       })
+# db = SQLAlchemy(model_class=declarative_base(metadata=meta, cls=Model, name='Model'))
 db = SQLAlchemy()
 Table = db.Table
 Column = db.Column
@@ -148,7 +162,7 @@ class User(Base, UserMixin):
     current_login_ip    = Column( String(100) )
     login_count         = Column( Integer )
     active              = Column( Boolean() )
-    fs_uniquifier       = Column( String(UNIQUIFIER_LEN) )
+    fs_uniquifier       = Column( String(UNIQUIFIER_LEN), nullable=False )
     confirmed_at        = Column( DateTime() )
     roles               = relationship('Role', secondary='roles_users',
                           backref=backref('users', lazy='dynamic'))
@@ -202,12 +216,12 @@ class ManageLocalTables():
                 # remove from deactivate list; update all fields
                 if (user.id,localinterest.id) in alllocal:
                     localuser = alllocal.pop((user.id,localinterest.id))
-                    for copy_local_user_attr in copy_local_user_attrs:
-                        setattr(localuser, copy_local_user_attr, getattr(user, copy_local_user_attr))
                 # needs to be added
                 else:
-                    newlocal = self.localusermodel(user_id=user.id, interest_id=localinterest.id, active=True)
-                    self.db.session.add(newlocal)
+                    localuser = self.localusermodel(user_id=user.id, interest_id=localinterest.id, active=True)
+                    self.db.session.add(localuser)
+                for copy_local_user_attr in copy_local_user_attrs:
+                    setattr(localuser, copy_local_user_attr, getattr(user, copy_local_user_attr))
 
         # all remaining in alllocal need to be deactivated
         for user_id,interest_id in alllocal:
@@ -229,12 +243,12 @@ class ManageLocalTables():
             # remove from deactivate list; update active status
             if user.id in alllocal:
                 localuser = alllocal.pop(user.id)
-                for copy_local_user_attr in copy_local_user_attrs:
-                    setattr(localuser, copy_local_user_attr, getattr(user, copy_local_user_attr))
             # needs to be added
             else:
-                newlocal = self.localusermodel(user_id=user.id, active=user.active)
-                self.db.session.add(newlocal)
+                localuser = self.localusermodel(user_id=user.id, active=user.active)
+                self.db.session.add(localuser)
+            for copy_local_user_attr in copy_local_user_attrs:
+                setattr(localuser, copy_local_user_attr, getattr(user, copy_local_user_attr))
 
         # all remaining in alllocal need to be deactivated
         for user_id in alllocal:
